=========================
Minos Microservice Common
=========================

.. image:: https://codecov.io/gh/Clariteia/minos_microservice_common/branch/main/graph/badge.svg
  :target: https://codecov.io/gh/Clariteia/minos_microservice_common

.. image:: https://github.com/Clariteia/minos_microservice_common/actions/workflows/python-test.yml/badge.svg


Python Package with common Classes and Utilities used in Minos Microservices

Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_  and the `clariteia/minos-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`clariteia/minos-pypackage`: https://bitbucket.org/clariteia-devs/minos-pypackage/src/master/
